# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json

# Taken from https://gist.github.com/ndfred/b373eeafc4f5b0870c1b8857041289a9
# Fields gathered from the ZigBee Smart Energy Standard document
# 0702: Metering
# - 00: Reading Information Set
#   - 00: CurrentSummationDelivered: meter reading
#   - 01: CurrentSummationReceived
#   - 02: CurrentMaxDemandDelivered
#   - 07: ReadingSnapshotTime (UTC time)
#   - 14: Supply Status (enum): 0x2 is on
# - 02: Meter Status
#   - 00: Status (bit map): 10 means power quality event
# - 03: Formatting
#   - 00: UnitofMeasure (enum): 00 means kWh, 01 means m3
#   - 01: Multiplier
#   - 02: Divisor
#   - 03: SummationFormatting (bit map):
#         2B means 3 digits after the decimal point, 2 digits before.
#         FB means 3 digits after the decimal point, 16 digits before.
#         no leading zeros
#   - 04: DemandFormatting
#   - 06: MeteringDeviceType: 00 means Electric Metering,
#                             80 means Mirrored Gas Metering
#   - 07: SiteID: MPAN encoded in UTF-8
#   - 08: MeterSerialNumber (string)
#   - 12: AlternativeUnitofMeasure (enum)
# - 04: Historical Consumption
#   - 00: InstantaneousDemand (signed): current consumption
#   - 01: CurrentDayConsumptionDelivered
#   - 30: CurrentWeekConsumptionDelivered
#   - 40: CurrentMonthConsumptionDelivered
# - 0C: Alternative Historical Consumption
#   - 01: CurrentDayConsumptionDelivered
#   - 30: CurrentWeekConsumptionDelivered
#   - 40: CurrentMonthConsumptionDelivered
# 0705: Prepayment
# - 00: Prepayment Information Set
#   - 00: PaymentControlConfiguration (bit map)
#   - 01: CreditRemaining (signed)
# 0708: Device Management
# - 01: Supplier Control Attribute Set
#   - 01: ProviderName (string)


METRIC = "glowprom_consumption{{type=\"{type}\",period=\"{period}\"}} {value}"
METER = "glowprom_meter{{type=\"{type}\"}} {value}"

METRIC_HELP = "# HELP glowprom_consumption" \
            + " The consumption over the given period."
METRIC_TYPE = "# TYPE glowprom_consumption counter"

METER_HELP = "# HELP glowprom_meter The meter reading."
METER_TYPE = "# TYPE glowprom_meter counter"


def cloud_message(msg):
    # Code adapted from
    # https://gist.github.com/ndfred/b373eeafc4f5b0870c1b8857041289a9
    payload = json.loads(msg.payload)

    elecMtr = payload["elecMtr"]["0702"]

    metrics, meters = [], []
    if "04" not in elecMtr:
        print("04 not found in electricity payload")
        print(payload)
    else:
        elec_consumption = int(elecMtr["04"]["00"], 16)
        elec_daily_consumption = int(elecMtr["04"]["01"], 16)
        elec_weekly_consumption = int(elecMtr["04"]["30"], 16)
        elec_monthly_consumption = int(elecMtr["04"]["40"], 16)
        elec_multiplier = int(elecMtr["03"]["01"], 16)
        elec_divisor = float(int(elecMtr["03"]["02"], 16))
        elec_meter = int(elecMtr["00"]["00"], 16)

        elec_daily_consumption = elec_daily_consumption * \
            elec_multiplier / elec_divisor
        elec_weekly_consumption = elec_weekly_consumption * \
            elec_multiplier / elec_divisor
        elec_monthly_consumption = elec_monthly_consumption * \
            elec_multiplier / elec_divisor
        electricity_meter = elec_meter * elec_multiplier / elec_divisor

        metrics.extend([
            METRIC.format(type="electricity",
                          period="daily",
                          value=elec_daily_consumption),
            METRIC.format(type="electricity",
                          period="weekly",
                          value=elec_weekly_consumption),
            METRIC.format(type="electricity",
                          period="monthly",
                          value=elec_monthly_consumption)])

        meters.append(METER.format(type="electricity",
                                   value=electricity_meter))

    gasMtr = payload["gasMtr"]["0702"]

    if "0C" not in gasMtr:
        print("0C not found in gas payload")
        print(payload)
    else:
        gas_daily_consumption = int(gasMtr["0C"]["01"], 16)
        gas_weekly_consumption = int(gasMtr["0C"]["30"], 16)
        gas_monthly_consumption = int(gasMtr["0C"]["40"], 16)
        gas_multiplier = int(gasMtr["03"]["01"], 16)
        gas_divisor = float(int(gasMtr["03"]["02"], 16))
        gas_meter = int(gasMtr["00"]["00"], 16)

        gas_daily_consumption = gas_daily_consumption * \
            gas_multiplier / gas_divisor
        gas_weekly_consumption = gas_weekly_consumption * \
            gas_multiplier / gas_divisor
        gas_monthly_consumption = gas_monthly_consumption * \
            gas_multiplier / gas_divisor
        gas_meter = gas_meter * gas_multiplier / gas_divisor

        metrics.extend([
            METRIC.format(type="gas",
                          period="daily",
                          value=gas_daily_consumption),
            METRIC.format(type="gas",
                          period="weekly",
                          value=gas_weekly_consumption),
            METRIC.format(type="gas",
                          period="monthly",
                          value=gas_monthly_consumption)])

        meters.append(METER.format(type="gas", value=gas_meter))

    return "\n".join([METRIC_HELP, METRIC_TYPE] + metrics + [
        METER_HELP, METER_TYPE] + meters)



# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
import json

# {'electricitymeter': {'timestamp': '2022-11-07T09:20:08Z',
#   'energy': {'export': {'cumulative': 0.0, 'units': 'kWh'},
#              'import': {'cumulative': 15254.827, 'day': 3.717,
#                         'week': 3.717, 'month': 60.439, 'units': 'kWh',
#                         'mpan': 'abcd', 'supplier': 'Octopus Energy',
#                         'price': {'unitrate': 0.16401,
#                                   'standingcharge': 0.19383}}},
#   'power': {'value': 0.425, 'units': 'kW'}}}

# {'gasmeter': {'timestamp': '2022-11-07T09:35:38Z',
#   'energy': {'import': {'cumulative': 66589.57, 'day': 17.326,
#                         'week': 17.326, 'month': 383.157, 'units': 'kWh',
#                         'cumulativevol': 5995.276,
#                         'cumulativevolunits': 'm3',
#                         'dayvol': 17.326, 'weekvol': 17.326,
#                         'monthvol': 383.157,
#                         'dayweekmonthvolunits': 'kWh',
#                         'mprn': 'wxyz',
#                         'supplier': '---',
#                         'price': {'unitrate': 0.03623,
#                                   'standingcharge': 0.168}}}}}
METRIC = "glowprom_{metric}"
METRIC_KEYS = "{{type=\"{type}\", {idname}=\"{idvalue}\"}}"

METRIC_METADATA = {
    "timestamp": ("The time the last update was received.", "counter", False),
    "export_cumulative": ("The total amount of energy exported.",
                          "counter", True),
    "import_cumulative": ("The total amount of energy imported.",
                          "counter", True),
    "import_day": ("The amount of energy imported today.", "gauge", True),
    "import_week": ("The amount of energy imported this week.", "gauge", True),
    "import_month": ("The amount of energy imported this month.",
                     "gauge", True),
    "import_price": ("The current unit price for energy.", "gauge", False),
    "import_standing": ("The standing charge for energy.", "gauge", False),
    "power": ("The current amount of power being used.", "gauge", True),
    "import_cumulativevol": ("The total volume of gas imported.",
                             "counter", True),
    "import_dayvol": ("The volume of gas imported today.", "counter", True),
    "import_weekvol": ("The volume of gas imported this week.",
                       "counter", True),
    "import_monthvol": ("The volume of gas imported this month.",
                        "counter", True)
}

METRIC_HELP = "# HELP {metric} {help}"
METRIC_TYPE = "# TYPE {metric} {type}"

ELECTRIC_DATA = {}
GAS_DATA = {}


def local_message(msg):
    # # Code adapted from
    # # https://gist.github.com/ndfred/b373eeafc4f5b0870c1b8857041289a9
    payload = json.loads(msg.payload)

    key = list(payload.keys())[0]
    energy = payload[key]["energy"]

    timestamp = datetime.datetime.strptime(payload[key]["timestamp"],
                                           r"%Y-%m-%dT%H:%M:%SZ").timestamp()

    if key == "electricitymeter":
        mpan = energy["import"]["mpan"]
        if mpan.lower() == "read pending":
            return
        if mpan not in ELECTRIC_DATA:
            ELECTRIC_DATA[mpan] = {}
        ELECTRIC_DATA[mpan]["timestamp"] = timestamp
        ELECTRIC_DATA[mpan]["export_cumulative"] = \
            convert_units(energy["export"]["cumulative"],
                          energy["export"]["units"])
        ELECTRIC_DATA[mpan]["import_cumulative"] = \
            convert_units(energy["import"]["cumulative"],
                          energy["import"]["units"])
        ELECTRIC_DATA[mpan]["import_day"] = \
            convert_units(energy["import"]["day"],
                          energy["import"]["units"])
        ELECTRIC_DATA[mpan]["import_week"] = \
            convert_units(energy["import"]["week"],
                          energy["import"]["units"])
        ELECTRIC_DATA[mpan]["import_month"] = \
            convert_units(energy["import"]["month"],
                          energy["import"]["units"])
        ELECTRIC_DATA[mpan]["import_price"] = \
            energy["import"]["price"]["unitrate"]
        ELECTRIC_DATA[mpan]["import_standing"] = \
            energy["import"]["price"]["standingcharge"]
        ELECTRIC_DATA[mpan]["power"] = \
            convert_units(payload[key]["power"]["value"],
                          payload[key]["power"]["units"])

    elif key == "gasmeter":
        mprn = energy["import"]["mprn"]
        if mprn.lower() == "read pending":
            return
        if mprn not in GAS_DATA:
            GAS_DATA[mprn] = {}
        GAS_DATA[mprn]["timestamp"] = timestamp
        GAS_DATA[mprn]["import_cumulative"] = \
            convert_units(energy["import"]["cumulative"],
                          energy["import"]["units"])
        GAS_DATA[mprn]["import_day"] = \
            convert_units(energy["import"]["day"], energy["import"]["units"])
        GAS_DATA[mprn]["import_week"] = \
            convert_units(energy["import"]["week"], energy["import"]["units"])
        GAS_DATA[mprn]["import_month"] = \
            convert_units(energy["import"]["month"], energy["import"]["units"])
        GAS_DATA[mprn]["import_cumulativevol"] = \
            convert_units(energy["import"]["cumulativevol"],
                          energy["import"]["cumulativevolunits"])
        GAS_DATA[mprn]["import_dayvol"] = \
            convert_units(energy["import"]["dayvol"],
                          energy["import"]["dayweekmonthvolunits"])
        GAS_DATA[mprn]["import_weekvol"] = \
            convert_units(energy["import"]["weekvol"],
                          energy["import"]["dayweekmonthvolunits"])
        GAS_DATA[mprn]["import_monthvol"] = \
            convert_units(energy["import"]["monthvol"],
                          energy["import"]["dayweekmonthvolunits"])
        GAS_DATA[mprn]["import_price"] = energy["import"]["price"]["unitrate"]
        GAS_DATA[mprn]["import_standing"] = \
            energy["import"]["price"]["standingcharge"]
    else:
        print(f"Unknown payload type {key}")

    lines = []
    for metric in METRIC_METADATA.keys():
        help, metric_type, has_units = METRIC_METADATA[metric]

        if has_units:
            for unit in get_units_for_metric(metric):
                metric_name = METRIC.format(metric=metric) + "_" + unit
                lines.append(METRIC_HELP.format(metric=metric_name,
                                                help=help))
                lines.append(METRIC_TYPE.format(metric=metric_name,
                                                type=metric_type))
        else:
            metric_name = METRIC.format(metric=metric)
            lines.append(METRIC_HELP.format(metric=metric_name,
                                            help=help))
            lines.append(METRIC_TYPE.format(metric=metric_name,
                                            type=metric_type))

        for mpan in ELECTRIC_DATA:
            if metric in ELECTRIC_DATA[mpan]:
                if has_units:
                    value = ELECTRIC_DATA[mpan][metric][0]
                    metric_name = \
                        METRIC.format(metric=metric) + "_" \
                        + ELECTRIC_DATA[mpan][metric][1]
                else:
                    value = ELECTRIC_DATA[mpan][metric]
                    metric_name = METRIC.format(metric=metric)

                keys = METRIC_KEYS.format(type="electric", idname="mpan",
                                          idvalue=mpan)
                lines.append(f"{metric_name}{keys} {value}")

        for mprn in GAS_DATA:
            if metric in GAS_DATA[mprn]:
                if has_units:
                    value = GAS_DATA[mprn][metric][0]
                    metric_name = METRIC.format(metric=metric) + "_" \
                        + GAS_DATA[mprn][metric][1]
                else:
                    value = GAS_DATA[mprn][metric]
                    metric_name = METRIC.format(metric=metric)

                keys = METRIC_KEYS.format(type="gas", idname="mprn",
                                          idvalue=mprn)
                lines.append(f"{metric_name}{keys} {value}")

        lines.append("")

    return "\n".join(lines)


def get_units_for_metric(metric):
    units = set()
    for mpan in ELECTRIC_DATA.keys():
        if metric in ELECTRIC_DATA[mpan]:
            units.add(ELECTRIC_DATA[mpan][metric][1])
    for mprn in GAS_DATA.keys():
        if metric in GAS_DATA[mprn]:
            units.add(GAS_DATA[mprn][metric][1])
    return units


def convert_units(value, units):
    if units == "kW":
        return (value * 1000, "W")
    if units == "kWh":
        return (value * 1000, "Wh")
    return (value, units)



# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json
import unittest

from glowprom.local_message import local_message


ELECTRIC_MESSAGE_TEXT = open("tests/test_local_electric_message.txt", "rb") \
                        .read()
GAS_MESSAGE_TEXT = open("tests/test_local_gas_message.txt", "rb").read()


class MockMessage:
    def __init__(self, payload):
        self.payload = payload


class TestLocalMessage(unittest.TestCase):
    def test_electric_message(self):
        prom = local_message(MockMessage(ELECTRIC_MESSAGE_TEXT))

        self.assertIn(
            "glowprom_import_cumulative_Wh{type=\"electric\", mpan=\"abcd\"}"
            + " 15254827.0", prom)

    def test_gas_message(self):
        prom = local_message(MockMessage(GAS_MESSAGE_TEXT))

        self.assertIn(
            "glowprom_import_cumulative_Wh{type=\"gas\", mprn=\"wxyz\"}"
            + " 66589570.00000001", prom)



# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json
import unittest

from glowprom.cloud_message import cloud_message


MESSAGE_TEXT = open("tests/test_message.txt", "rb").read()


class MockMessage:
    def __init__(self, payload):
        self.payload = payload


class TestCloudMessage(unittest.TestCase):
    def test_cloud_message(self):
        prom = cloud_message(MockMessage(MESSAGE_TEXT))

        self.assertIn(
            "glowprom_consumption{type=\"electricity\",period=\"daily\"} "
            + "7.971", prom)
        self.assertIn(
            "glowprom_consumption{type=\"gas\",period=\"daily\"} 39.452",
            prom)

    def test_missing_electricity(self):
        data = json.loads(MESSAGE_TEXT)
        del data["elecMtr"]["0702"]["04"]
        prom = cloud_message(MockMessage(json.dumps(data)))

        self.assertNotIn(
            "glowprom_consumption{type=\"electricity\",period=\"daily\"} "
            + "7.971", prom)
        self.assertIn(
            "glowprom_consumption{type=\"gas\",period=\"daily\"} 39.452", prom)

    def test_missing_gas(self):
        data = json.loads(MESSAGE_TEXT)
        del data["gasMtr"]["0702"]["0C"]
        prom = cloud_message(MockMessage(json.dumps(data)))

        self.assertIn(
            "glowprom_consumption{type=\"electricity\",period=\"daily\"} "
            + "7.971", prom)
        self.assertNotIn(
            "glowprom_consumption{type=\"gas\",period=\"daily\"} 39.452", prom)



# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import unittest

from glowprom import get_arguments, InvalidArguments


class TestArguments(unittest.TestCase):
    def setUp(self):
        os.environ = {}

    def test_user_environ(self):
        os.environ["GLOWPROM_USER"] = "testuser"
        args = get_arguments(["--passwd", "testpassword", "--topic", "topic"])
        self.assertEqual("testuser", args.user)
        self.assertEqual("testpassword", args.passwd)

    def test_passwd_environ(self):
        os.environ["GLOWPROM_PASSWD"] = "testpassword"
        args = get_arguments(["--user", "testuser", "--topic", "topic"])
        self.assertEqual("testpassword", args.passwd)

    def test_passwd_environ(self):
        os.environ["GLOWPROM_TOPIC"] = "topic"
        args = get_arguments(["--user", "testuser",
                              "--passwd", "testpassword"])
        self.assertEqual("topic", args.topic)

    def test_bind_without_port(self):
        os.environ["GLOWPROM_USER"] = "testuser"
        os.environ["GLOWPROM_PASSWD"] = "testpassword"
        os.environ["GLOWPROM_TOPIC"] = "topic"
        args = get_arguments(["--bind", "192.168.1.2"])
        self.assertEqual("192.168.1.2", args.bind[0])
        self.assertEqual(9100, args.bind[1])

    def test_no_user(self):
        os.environ["GLOWPROM_PASSWD"] = "testpasswd"
        os.environ["GLOWPROM_TOPIC"] = "topic"
        self.assertRaises(InvalidArguments, get_arguments, [])

    def test_no_passwd(self):
        os.environ["GLOWPROM_USER"] = "testuser"
        os.environ["GLOWPROM_TOPIC"] = "topic"
        self.assertRaises(InvalidArguments, get_arguments, [])

    def test_no_topic(self):
        os.environ["GLOWPROM_USER"] = "testuser"
        os.environ["GLOWPROM_PASSWD"] = "testpasswd"
        self.assertRaises(InvalidArguments, get_arguments, [])



# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import functools
import time
import traceback
import sys

import paho.mqtt.client as mqtt


def on_connect(topic, client, userdata, flags, rc):
    print("Connected with result code "+str(rc))

    client.subscribe(topic)


def safe_on_message(on_message):
    def safe_on_message(client, userdata, msg):
        try:
            return on_message(client, userdata, msg)
        except Exception as e:
            sys.stderr.write(f"Exception processing message: {msg}\n")

            traceback.print_exc()

    return safe_on_message


def connect(args, on_message, retry=True):
    client = mqtt.Client()
    client.on_connect = \
        functools.partial(on_connect,
                          args.topic if args.cloud else "glow/+/+/+")
    client.on_message = safe_on_message(on_message)

    client.username_pw_set(args.user, password=args.passwd)

    while True:
        try:
            client.connect(args.mqtt, args.port, 60)
        except Exception as e:
            if not retry:
                raise
            print(e)
            time.sleep(10)
        else:
            break

    client.loop_forever()



# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from datetime import datetime
import http.server

from .cloud_message import cloud_message
from .local_message import local_message


STATS = None


class Handler(http.server.BaseHTTPRequestHandler):
    def do_GET(self):
        if self.path == "/":
            self.send_index()
        elif self.path == "/metrics":
            self.send_metrics()
        else:
            self.send_error(404)

    def send_index(self):
        self.send_response(200)
        self.end_headers()
        self.wfile.write("""
<html>
<head><title>Glow Prometheus</title></head>
<body>
<h1>Glow Prometheus</h1>
<p><a href="/metrics">Metrics</a></p>
</body>
</html>""".encode("utf8"))

    def send_metrics(self):
        if STATS is None:
            self.send_response(404)
            self.end_headers()
        else:
            self.send_response(200)
            self.end_headers()
            self.wfile.write(STATS.encode("utf8"))


def serve(args):  # pragma: no cover
    server = http.server.HTTPServer(args.bind, Handler)
    server.serve_forever()


def update_stats(cloud):
    prometheus = cloud_message if cloud else local_message

    def update_stats(client, userdata, msg):
        global STATS
        if msg is None:
            STATS = None
        else:
            STATS = prometheus(msg)
    return update_stats



# glowprom
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import setuptools

from glowprom import __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

setuptools.setup(
    name="glowprom", # Replace with your own username
    version=__version__,
    author="Andrew Wilkinson",
    author_email="andrewjwilkinson@gmail.com",
    description="Receives gas and electric meter data from https://glowmarkt.com/ and exposes it to Prometheus.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/andrewjw/glowprom",
    packages=setuptools.find_packages(),
    scripts=["bin/glowprom"],
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
    install_requires=requirements,
)
